"use client";
import FormButtons from "@/components/simulation/common/form-buttons";
import Sidebar from "@/components/simulation/common/sidebar";
import { ImageBaseUrl } from "@/configs/api";
import { selectPoolComponents } from "@/servers/actions/pool-request-action";
import { usePoolRequestInfo } from "@/servers/data/use-pool-request-info";
import { useProduct } from "@/servers/data/use-product";
import { useTranslations } from "next-intl";
import dynamic from "next/dynamic";
import { useRouter, useSearchParams } from "next/navigation";
import React, { useState, useTransition } from "react";
import { toast } from "sonner";
const Scene = dynamic(() => import("@/components/swimming-pool/scene"));

// Constants
const LADDER_MODELS = {
	POOL_1: "/storage/attachments/products/models/1745147542_ladder1.1.glb",
	POOL_2: "/storage/attachments/products/models/1745147780_ladder1.2.glb"
};

const DefaultSelect = { pool: 1, showWater: true, floor: 1, ladder: 0, waterfall: 0, jacuzzi: 0, lamp: 0, selectedProduct: null };

export default function PoolLadders() {
	const t = useTranslations();
	const router = useRouter();
	const searchParams = useSearchParams();
	const [showItem, setShowItem] = useState<any>(DefaultSelect);
	const [isPending, startTransition] = useTransition();
	const [products, setProducts] = useState<any[]>([]);

	// Fetch ladders products
	const { products: laddersProducts, isLoading } = useProduct({ product_type: "ladder" });
	const { poolRequestInfo } = usePoolRequestInfo();

	// Update showItem based on URL parameters
	React.useEffect(() => {
		const pool = searchParams.get("pool");
		const tile = searchParams.get("tile");

		if (pool) {
			setShowItem((prev: any) => ({ ...prev, pool: parseInt(pool) }));
		}

		if (tile) {
			setShowItem((prev: any) => ({
				...prev,
				selectedTile: {
					id: parseInt(tile),
					texture: poolRequestInfo?.data?.tiles?.[0]?.tile?.texture,
					model_3d: poolRequestInfo?.data?.tiles?.[0]?.tile?.model_3d
				}
			}));
		}
	}, [searchParams, poolRequestInfo]);

	React.useEffect(() => {
		if (laddersProducts?.data?.length > 0) {
			setShowItem((prev: typeof DefaultSelect) => ({ ...prev, selectedLadder: { id: laddersProducts?.data[0]?.id, texture: laddersProducts?.data[0]?.texture, model_3d: laddersProducts?.data[0]?.model_3d } }));
		}
	}, [laddersProducts]);

	React.useEffect(() => {
		const pool = searchParams.get("pool");
		const poolNumber = pool ? parseInt(pool) : null;
		console.log("poolNumber: ", poolNumber);
		if (poolNumber === 1) {
			setProducts(
				laddersProducts?.data
					?.filter((product: any) => product?.model_3d === LADDER_MODELS.POOL_1)
					?.map((product: any) => ({
						id: product?.id,
						texture: product?.texture,
						name_en: product?.name_en,
						model_3d: product?.model_3d
					})) || []
			);
		}

		if (poolNumber === 2) {
			setProducts(
				laddersProducts?.data
					?.filter((product: any) => product?.model_3d === LADDER_MODELS.POOL_2)
					?.map((product: any) => ({
						id: product?.id,
						texture: product?.texture,
						name_en: product?.name_en,
						model_3d: product?.model_3d
					})) || []
			);
		}
	}, [laddersProducts, searchParams]);

	const _ladders = React.useMemo(() => ({
		title: t("Type of ladders"),
		path: "ladder",
		images: products?.map((product: any) => ({
			src: ImageBaseUrl + product?.images?.[0]?.image_path,
			alt: product?.name_en,
			data: {
				floor: product?.id,
				selectedLadder: {
					id: product?.id,
					texture: product?.texture,
					name: product?.name_en,
					model_3d: product?.model_3d
				}
			}
		})) || [],
		position: {
			position: { "x": -0.05628295057098927, "y": 1.4, "z": -0.4 },
			target: { "x": -0.004731949370818576, "y": -0.9980694513612546, "z": 0.06192720657833983 }
		}
	}), [t, products]);

	console.log("showItem", showItem);
	const handleNextPage = async () => {
		if (showItem.selectedLadder?.id) {
			const response = await selectPoolComponents({ product_id: showItem.selectedLadder?.id, type: "ladder" });
			console.log("response: ", response);
			if (!response.success) {
				toast.error(response.message);
			}
		}

		startTransition(() => {
			router.push(`/simulation-program/pool-lights?pool=${showItem.pool}&tile=${showItem.selectedTile?.id}&ladder=${showItem.selectedLadder?.id}&light=${showItem.selectedLight?.id}` as any);
		});
	};

	return (
		<div className="h-screen w-full start-bg">
			<div className="flex h-full">
				<div className="w-full flex items-center justify-center">
					{showItem.selectedLadder?.id && <FormButtons
						onPrevious={() => router.back()}
						onNext={handleNextPage}
						isPending={isPending}
					/>}
					<Scene showItem={showItem} cameraSetting={_ladders?.position} />
					<Sidebar
						title={_ladders?.title}
						images={_ladders?.images}
						setShowItem={setShowItem}
						showItem={showItem}
						isLoading={isLoading}
					/>
				</div>
			</div>
		</div>
	);
}
